--- src/notation/view/abstractnotationpaintview.cpp.orig	2025-12-01 12:36:11 UTC
+++ src/notation/view/abstractnotationpaintview.cpp
@@ -21,6 +21,7 @@
  */
 #include "abstractnotationpaintview.h"
 
+#include <QCursor>
 #include <QPainter>
 #include <QMimeData>
 
