--- src/qmapshack/mouse/IMouseSelect.cpp.orig	2025-07-04 12:38:57 UTC
+++ src/qmapshack/mouse/IMouseSelect.cpp
@@ -21,6 +21,7 @@
 
 #include <QPainterPath>
 #include <QtWidgets>
+#include <QPainterPath>
 
 #include "gis/CGisDraw.h"
 #include "mouse/CMouseAdapter.h"
