--- inc/Standard_Time.hxx.orig	2017-08-30 13:28:31 UTC
+++ inc/Standard_Time.hxx
@@ -26,11 +26,11 @@
 // ------------------------------------------------------------------
 // IsEqual : Returns Standard_True if two time values are equal
 // ------------------------------------------------------------------
-inline Standard_Boolean IsEqual (const Standard_Time theOne,
-                                 const Standard_Time theTwo)
-{
-  return theOne == theTwo;
-}
+//inline Standard_Boolean IsEqual (const Standard_Time theOne,
+//                                 const Standard_Time theTwo)
+//{
+//  return theOne == theTwo;
+//}
 
 #endif
 
