--- src/control/defaults.h.orig	2012-05-01 21:38:26 UTC
+++ src/control/defaults.h
@@ -3,6 +3,7 @@
 #ifndef DEFAULTS_H
 #define DEFAULTS_H
 
+#include <ctime>
 #include <string>
 #include "constants.h"
 #include "local_build.h"
