--- app/src/usb/aoa_hid.c.orig	2025-04-20 01:48:34 UTC
+++ app/src/usb/aoa_hid.c
@@ -5,7 +5,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/types.h>
-#include <libusb-1.0/libusb.h>
+#include <libusb.h>
 
 #include "events.h"
 #include "util/log.h"
