--- input/vorbis/oggstat.h.orig	2004-09-15 23:03:59 UTC
+++ input/vorbis/oggstat.h
@@ -5,6 +5,7 @@
 #include <sys/mman.h>
 #include <fcntl.h>
 #include <string>
+#include <cstdio>
 #include <vorbis/codec.h>
 
 #include "input.h"
