--- awl/knob.h.orig	2023-08-03 19:28:45 UTC
+++ awl/knob.h
@@ -30,6 +30,7 @@
 #include <QSize>
 
 #include "aslider.h"
+#include <QPainterPath>
 // #include <QtDesigner/QDesignerExportWidget>
 
 namespace Awl {
