--- src/StringUtils.cpp.orig	2018-03-13 02:38:23 UTC
+++ src/StringUtils.cpp
@@ -22,6 +22,7 @@
 #include <cstdio>
 #include <iostream>
 #include <sstream>
+#include <sys/types.h>	// uint
 
 #include "StringUtils.hpp"
 
