--- src/misc/TMemoryPipe.h.orig	2013-03-29 17:15:58 UTC
+++ src/misc/TMemoryPipe.h
@@ -24,6 +24,7 @@
 #include "../../config/common.h"
 
 #include <stdexcept>
+#include <string>
 
 #include "CMutex.h"
 #include "CConditionVariable.h"
