--- lib/mysqlsla.pm.orig	2014-09-19 19:35:03 UTC
+++ lib/mysqlsla.pm
@@ -6,6 +6,8 @@
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 mysqlsla - Parse, filter, analyze and sort MySQL slow, general and binary logs
