--- tests/fff_print/test_data.cpp.orig	2025-04-10 11:26:51 UTC
+++ tests/fff_print/test_data.cpp
@@ -11,6 +11,7 @@
 #include <arrange-wrapper/ModelArrange.hpp>
 
 #include <cstdlib>
+#include <fstream>
 #include <string>
 
 #include <boost/nowide/cstdio.hpp>
