--- src/common/mathmisc.h.orig	2024-10-25 16:26:08 UTC
+++ src/common/mathmisc.h
@@ -24,6 +24,7 @@
 #ifndef RUBBERBAND_MATHMISC_H
 #define RUBBERBAND_MATHMISC_H
 
+#include <stddef.h>
 #include "sysutils.h"
 
 #ifndef M_PI
