--- src/graph/graphqtdlg.h.orig	2004-07-16 01:59:53 UTC
+++ src/graph/graphqtdlg.h
@@ -59,6 +59,7 @@ struct Idialogitem;
 class QSignalMapper;
 class EScrollField;
 class EDialogPrivate;
+class EDialog;
 
 class EDialogPrivate: public QDialog
 {
